@@ -3,7 +3,10 @@
 
 #include <QDialog>
 #include <QTimer>
-
+/*#ifdef Q_OS_SYMBIAN
+    #include <applications/qtcontacts.h>
+    using namespace QtMobility;
+#endif*/
 #ifdef Q_WS_MAEMO_5
     #include <QContact>
     using namespace QtMobility;
@@ -32,7 +35,7 @@ private:
     QTimer* m_Timer;
     QList<Contact*> m_Contacts;
     QString m_Selected;    
-    void AddContactToList(Contact* c, int index);
+    void AddContactToList(Contact* c, int index, QPixmap* defaultImage);
 
 private slots:
     void TimerSlot();
