@@ -12,18 +12,19 @@ Counter::Counter()
 
 QString Counter::ToString()
 {
-    return QString("%1;%2;%3;%4;%5;%6;%7;%8;%9;%10;%11;%12")
+    return QString("%1;%2;%3;%4;%5;%6;%7;%8;%9;%10;%11;%12;%13")
            .arg(Description).arg(Type).arg(Class).arg(Code)
            .arg(SogliaDisplayType).arg(Soglia).arg(Utilizzato)
            .arg(Residuo).arg(Scatto).arg(DimensioneScatto)
-           .arg(Periodo.toString("dd/MM/yyyy")).arg(DataUtile.toString("dd/MM/yyyy"));
+           .arg(Periodo.toString("dd/MM/yyyy")).arg(DataUtile.toString("dd/MM/yyyy"))
+           .arg(Unita);
 }
 
-void Counter::FromString(QString string)
+bool Counter::FromString(QString string)
 {
     QStringList list = string.split(';');
-    if (list.count() < 12)
-        return;
+    if (list.count() < 13)
+        return false;
 
     Description = list.at(0);
     Type = list.at(1);
@@ -37,4 +38,7 @@ void Counter::FromString(QString string)
     DimensioneScatto = list.at(9);
     Periodo = QDate::fromString(list.at(10), "dd/MM/yyyy");
     DataUtile = QDate::fromString(list.at(11), "dd/MM/yyyy");
+    Unita = list.at(12);
+
+    return true;
 }
