@@ -29,6 +29,7 @@ private:
 
     QMovie* m_WaitIcon;
     Settings* m_Settings;
+    QMenu* m_MainMenu;
     QAction* m_SettingsAction;
     QAction* m_AboutAction;
     QAction* m_QuitAction;
@@ -39,7 +40,8 @@ private:
     QList<Counter*>* m_Counters;
     void Update();
     void closeEvent(QCloseEvent *event);
-    void SetUpdatedLabel(QDateTime date);
+    void SetUpdatedLabel(QDateTime date);    
+    void RefreshCounterWidgets();
 
 private slots:
     void TimerSlot();
