@@ -22,9 +22,9 @@ VodafoneWidget::~VodafoneWidget()
     m_Nam = NULL;
 } // ~VodafoneWidget
 
-void VodafoneWidget::SetCredentials(QString username, QString password, bool logout)
+void VodafoneWidget::SetCredentials(QString username, QString password)
 {
-    if (logout)
+    if ((!m_Username.isEmpty() && m_Username != username) || (!m_Password.isEmpty() && m_Password != password))
         Logout();
     m_Username = username;
     m_Password = password;
@@ -115,16 +115,19 @@ void VodafoneWidget::Logout()
     SynchRequest(&request);
 } // Logout
 
-QNetworkRequest VodafoneWidget::PrepareRequest(QUrl url)
+QNetworkRequest VodafoneWidget::PrepareRequest(QUrl url, bool vodafoneUserAgent)
 {
-    return PrepareRequest(url.toString());
+    return PrepareRequest(url.toString(), vodafoneUserAgent);
 } // PrepareRequest
 
-QNetworkRequest VodafoneWidget::PrepareRequest(QString url)
+QNetworkRequest VodafoneWidget::PrepareRequest(QString url, bool vodafoneUserAgent)
 {
     QUrl tUrl(url);
     QNetworkRequest request(tUrl);
-    request.setRawHeader("User-Agent", "Vodafone_DW");
+    if (vodafoneUserAgent)
+        request.setRawHeader("User-Agent", "VODAFONE_DW");
+    else
+        request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; U; Linux i686; pl-PL; rv:1.9.0.2) Gecko/20121223 Ubuntu/9.25 (jaunty) Firefox/3.8");
     return request;
 } // PrepareRequest
 
@@ -242,11 +245,11 @@ bool VodafoneWidget::GetInfoConto(InfoConto* info)
     return true;
 }
 
-QList<Counter*>* VodafoneWidget::GetListaContatori()
+QList<Counter*>* VodafoneWidget::GetListaContatori(bool includeStandard)
 {
     QList<Counter*>* result = new QList<Counter*>();
 
-    QNetworkRequest request = PrepareRequest("https://widget.vodafone.it/190/ebwe/mx/Desktopwidgetconto.do");
+    QNetworkRequest request = PrepareRequest("https://widget.vodafone.it/190/ebwe/mx/Desktopwidgetconto.do", !includeStandard);
     QString string = SynchRequest(&request);
     if (DebugXml)
         qDebug() << "GetListaContatori: " << string;
@@ -294,7 +297,7 @@ bool VodafoneWidget::GetDettaglioContatore(Counter* counter)
     url.addQueryItem("ProductType", counter->Type);
     url.addQueryItem("Classe", counter->Class);
     url.addQueryItem("ProductCode", counter->Code);
-    QNetworkRequest request = PrepareRequest(url);
+    QNetworkRequest request = PrepareRequest(url, false);
 
     QString string = SynchRequest(&request);
     if (DebugXml)
@@ -305,21 +308,25 @@ bool VodafoneWidget::GetDettaglioContatore(Counter* counter)
     if (GetReturnCode(doc) != "0")
         return false;
 
+    QString tempValue;
     QDomNode root = doc.firstChildElement("root");
     QDomNodeList list = root.firstChildElement("SogliaItem").childNodes();
     int found = 0;
     for (int i=0; i<list.count(); i++){
         QDomNode node = list.at(i);
         if (node.nodeName() == "Soglia"){
-            counter->Soglia = node.firstChild().nodeValue().toFloat();
+            tempValue = node.firstChild().nodeValue().replace(",", ".");
+            counter->Soglia = tempValue.toFloat();
             found++;
         }else if (node.nodeName() == "DisplayType"){
             counter->SogliaDisplayType = node.firstChild().nodeValue().toInt();
             found++;
         }else if (node.nodeName() == "TrafficoUtilizzato"){
+            tempValue = node.firstChild().nodeValue().replace(",", ".");
             counter->Utilizzato = node.firstChild().nodeValue().toFloat();
             found++;
-        }else if (node.nodeName() == "TrafficoResiduo"){
+        }else if (node.nodeName() == "TrafficoResiduo"){            
+            tempValue = node.firstChild().nodeValue().replace(",", ".");
             counter->Residuo = node.firstChild().nodeValue().toFloat();
             found++;
         }else if (node.nodeName() == "DimensioneScatto"){
@@ -329,6 +336,7 @@ bool VodafoneWidget::GetDettaglioContatore(Counter* counter)
             counter->Unita = node.firstChild().nodeValue();
             found++;
         }else if (node.nodeName() == "UnitaScatto"){
+            tempValue = node.firstChild().nodeValue().replace(",", ".");
             counter->Scatto = node.firstChild().nodeValue().toFloat();
             found++;
         }else if (node.nodeName() == "Periodo"){
