@@ -48,7 +48,7 @@ public:
      ~VodafoneWidget();
 
     bool DebugXml;
-    void SetCredentials(QString username, QString password, bool logout=true);
+    void SetCredentials(QString username, QString password);
     bool IsLoggedIn();
     bool Login();
     void Logout();
@@ -61,7 +61,7 @@ public:
 
     float GetCredito(QString* valuta);
     bool GetInfoConto(InfoConto* info);
-    QList<Counter*>* GetListaContatori();
+    QList<Counter*>* GetListaContatori(bool includeStandard=false);
     bool GetDettaglioContatore(Counter* counter);
     bool GetSaldoPunti(SaldoPunti* saldo);
 
@@ -87,8 +87,8 @@ private:
 
     QString GetReturnCode(QDomDocument doc);
     QString GetStatus(QDomDocument doc, QString* errorMessage=0);
-    QNetworkRequest PrepareRequest(QUrl url);
-    QNetworkRequest PrepareRequest(QString url);
+    QNetworkRequest PrepareRequest(QUrl url, bool vodafoneUserAgent=true);
+    QNetworkRequest PrepareRequest(QString url, bool vodafoneUserAgent=true);
     QString SynchRequest(QNetworkRequest* request, QUrl* redirectUrl=NULL);
 
     QString Decrypt(QString* crypted, QString* sessionID);
