@@ -19,13 +19,12 @@ private:
     QGridLayout* m_Layout;
 
     bool m_Pressed;
+    bool m_Sunken;
     void mousePressEvent(QMouseEvent* event);
     void mouseReleaseEvent(QMouseEvent* event);
     void leaveEvent(QEvent* event);
     void enterEvent(QEvent* event);
 
-    void SetStyle(bool selected);
-
 signals:
     void clicked();
 };
